@@ -30,6 +30,9 @@ class Client:
             method, url, auth=CosS3Auth(self.secret_id, self.secret_key, key), **kwargs,
         )
 
+    def head(self, key, **kwargs):
+        return self.request("HEAD", key, **kwargs)
+
     def get(self, key, **kwargs):
         return self.request("GET", key, **kwargs)
 
@@ -44,7 +47,7 @@ class Client:
 
     def put_local(self, key, local_path, **kwargs):
         with open(local_path, "rb") as f:
-            return self.request("PUT", key, data=f, **kwargs)
+            return self.smart_put_object(key, data=f.read(), **kwargs)
 
     def smart_put_object(self, key, data, content_type=None, headers={}, **kwargs):
         if isinstance(data, (dict, list)):
